pub struct ValidatorInternalNetworkPreConfig<P> {
pub public_key: ValidatorPublicKey,
pub protocol: P,
pub shards: Vec<ShardConfig>,
pub block_exporters: Vec<ExporterServiceConfig>,
pub proxies: Vec<ProxyConfig>,
}Expand description
The network configuration for all shards.
Fields
public_key: ValidatorPublicKeyThe public key of the validator.
protocol: PThe network protocol to use internally.
shards: Vec<ShardConfig>The available shards. Each chain UID is mapped to a unique shard in the vector in a static way.
block_exporters: Vec<ExporterServiceConfig>The server configurations for the linera-exporter. They can be used as optional locations to forward notifications to destinations other than the proxy, by the workers.
proxies: Vec<ProxyConfig>The available proxies.
Implementations
Sourceimpl<P> ValidatorInternalNetworkPreConfig<P>
impl<P> ValidatorInternalNetworkPreConfig<P>
pub fn clone_with_protocol<Q>( &self, protocol: Q, ) -> ValidatorInternalNetworkPreConfig<Q>
Sourceimpl ValidatorInternalNetworkPreConfig<NetworkProtocol>
impl ValidatorInternalNetworkPreConfig<NetworkProtocol>
pub fn exporter_addresses(&self) -> Vec<String>
Sourceimpl<P> ValidatorInternalNetworkPreConfig<P>
impl<P> ValidatorInternalNetworkPreConfig<P>
Sourcepub fn get_shard_id(&self, chain_id: ChainId) -> ShardId
pub fn get_shard_id(&self, chain_id: ChainId) -> ShardId
Static shard assignment
pub fn shard(&self, shard_id: ShardId) -> &ShardConfig
Sourcepub fn get_shard_for(&self, chain_id: ChainId) -> &ShardConfig
pub fn get_shard_for(&self, chain_id: ChainId) -> &ShardConfig
Gets the ShardConfig of the shard assigned to the chain_id.