pub struct BlockProposal {
pub chain_id: Option<ChainId>,
pub content: Vec<u8>,
pub owner: Option<AccountOwner>,
pub signature: Option<AccountSignature>,
pub original_proposal: Option<Vec<u8>>,
}Expand description
An authenticated proposal for a new block.
Fields
chain_id: Option<ChainId>The ID of the chain (used for routing).
content: Vec<u8>bincode-encoded content
owner: Option<AccountOwner>Byte-encoded owner
signature: Option<AccountSignature>Signature by chain owner
original_proposal: Option<Vec<u8>>A lite certificate for a validated block, or a fast block proposal, that justifies the proposal in this round.
Implementations
Sourceimpl BlockProposal
impl BlockProposal
Sourcepub fn original_proposal(&self) -> &[u8] ⓘ
pub fn original_proposal(&self) -> &[u8] ⓘ
Returns the value of original_proposal, or the default value if original_proposal is unset.