pub struct ChainInfoQuery {
pub chain_id: Option<ChainId>,
pub test_next_block_height: Option<BlockHeight>,
pub request_committees: bool,
pub request_pending_message_bundles: bool,
pub request_received_log_excluding_first_n: Option<u64>,
pub request_manager_values: bool,
pub request_leader_timeout: Option<Vec<u8>>,
pub request_owner_balance: Option<AccountOwner>,
pub request_fallback: bool,
pub request_sent_certificate_hashes_by_heights: Option<Vec<u8>>,
pub create_network_actions: Option<bool>,
}Expand description
Request information on a chain.
Fields
chain_id: Option<ChainId>The chain ID
test_next_block_height: Option<BlockHeight>Optionally test that the block height is as expected
request_committees: boolQuery the current committees
request_pending_message_bundles: boolQuery the received messages that are waiting to be picked in the next block.
request_received_log_excluding_first_n: Option<u64>Query new certificate removed from the chain.
request_manager_values: boolQuery values from the chain manager, not just votes.
request_leader_timeout: Option<Vec<u8>>Request a signed vote for a leader timeout for the given height and round.
request_owner_balance: Option<AccountOwner>Query the balance of a given owner.
request_fallback: boolRequest a signed vote for fallback mode.
request_sent_certificate_hashes_by_heights: Option<Vec<u8>>Query for certificate hashes at block heights sent from the chain.
create_network_actions: Option<bool>Whether to create network actions as part of the query.
Implementations
Sourceimpl ChainInfoQuery
impl ChainInfoQuery
Sourcepub fn request_received_log_excluding_first_n(&self) -> u64
pub fn request_received_log_excluding_first_n(&self) -> u64
Returns the value of request_received_log_excluding_first_n, or the default value if request_received_log_excluding_first_n is unset.
Sourcepub fn request_leader_timeout(&self) -> &[u8] ⓘ
pub fn request_leader_timeout(&self) -> &[u8] ⓘ
Returns the value of request_leader_timeout, or the default value if request_leader_timeout is unset.
Sourcepub fn request_sent_certificate_hashes_by_heights(&self) -> &[u8] ⓘ
pub fn request_sent_certificate_hashes_by_heights(&self) -> &[u8] ⓘ
Returns the value of request_sent_certificate_hashes_by_heights, or the default value if request_sent_certificate_hashes_by_heights is unset.
Sourcepub fn create_network_actions(&self) -> bool
pub fn create_network_actions(&self) -> bool
Returns the value of create_network_actions, or the default value if create_network_actions is unset.