pub struct CryptoHash {
pub bytes: Vec<u8>,
}Fields
bytes: Vec<u8>Trait Implementations
Sourceimpl Clone for CryptoHash
impl Clone for CryptoHash
Sourcefn clone(&self) -> CryptoHash
fn clone(&self) -> CryptoHash
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CryptoHash
impl Debug for CryptoHash
Sourceimpl Default for CryptoHash
impl Default for CryptoHash
impl Eq for CryptoHash
Sourceimpl From<CryptoHash> for CryptoHash
impl From<CryptoHash> for CryptoHash
Sourcefn from(hash: CryptoHash) -> Self
fn from(hash: CryptoHash) -> Self
Converts to this type from the input type.
Sourceimpl Hash for CryptoHash
impl Hash for CryptoHash
Sourceimpl Message for CryptoHash
impl Message for CryptoHash
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CryptoHash
impl PartialEq for CryptoHash
Sourcefn eq(&self, other: &CryptoHash) -> bool
fn eq(&self, other: &CryptoHash) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CryptoHash
Sourceimpl TryFrom<CryptoHash> for CryptoHash
impl TryFrom<CryptoHash> for CryptoHash
Sourcetype Error = GrpcProtoConversionError
type Error = GrpcProtoConversionError
The type returned in the event of a conversion error.