pub struct NetworkDescription {
pub name: String,
pub genesis_config_hash: Option<CryptoHash>,
pub genesis_timestamp: u64,
pub admin_chain_id: Option<ChainId>,
pub genesis_committee_blob_hash: Option<CryptoHash>,
}Fields
name: Stringgenesis_config_hash: Option<CryptoHash>genesis_timestamp: u64admin_chain_id: Option<ChainId>genesis_committee_blob_hash: Option<CryptoHash>Trait Implementations
Sourceimpl Clone for NetworkDescription
impl Clone for NetworkDescription
Sourcefn clone(&self) -> NetworkDescription
fn clone(&self) -> NetworkDescription
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NetworkDescription
impl Debug for NetworkDescription
Sourceimpl Default for NetworkDescription
impl Default for NetworkDescription
impl Eq for NetworkDescription
Sourceimpl From<NetworkDescription> for NetworkDescription
impl From<NetworkDescription> for NetworkDescription
Sourcefn from(_: NetworkDescription) -> Self
fn from(_: NetworkDescription) -> Self
Converts to this type from the input type.
Sourceimpl Hash for NetworkDescription
impl Hash for NetworkDescription
Sourceimpl Message for NetworkDescription
impl Message for NetworkDescription
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for NetworkDescription
impl PartialEq for NetworkDescription
Sourcefn eq(&self, other: &NetworkDescription) -> bool
fn eq(&self, other: &NetworkDescription) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NetworkDescription
Sourceimpl TryFrom<NetworkDescription> for NetworkDescription
impl TryFrom<NetworkDescription> for NetworkDescription
Sourcetype Error = GrpcProtoConversionError
type Error = GrpcProtoConversionError
The type returned in the event of a conversion error.