pub struct PreviousEventBlock {
pub stream_id: Option<StreamId>,
pub block_height: Option<BlockHeight>,
pub crypto_hash: Option<CryptoHash>,
}Expand description
An entry mapping a stream to its previous event block.
Fields
stream_id: Option<StreamId>block_height: Option<BlockHeight>crypto_hash: Option<CryptoHash>Trait Implementations
Sourceimpl Clone for PreviousEventBlock
impl Clone for PreviousEventBlock
Sourcefn clone(&self) -> PreviousEventBlock
fn clone(&self) -> PreviousEventBlock
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreviousEventBlock
impl Debug for PreviousEventBlock
Sourceimpl Default for PreviousEventBlock
impl Default for PreviousEventBlock
impl Eq for PreviousEventBlock
Sourceimpl Hash for PreviousEventBlock
impl Hash for PreviousEventBlock
Sourceimpl Message for PreviousEventBlock
impl Message for PreviousEventBlock
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PreviousEventBlock
impl PartialEq for PreviousEventBlock
Sourcefn eq(&self, other: &PreviousEventBlock) -> bool
fn eq(&self, other: &PreviousEventBlock) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PreviousEventBlock