UpdateRecipient

Struct UpdateRecipient 

pub struct UpdateRecipient {
    pub sender: Option<ChainId>,
    pub recipient: Option<ChainId>,
    pub bundles: Vec<u8>,
    pub previous_height: Option<BlockHeight>,
}
Communicate a number of messages from the sender to the recipient. Messages must be given by increasing block height.

Fields

sender: Option<ChainId>recipient: Option<ChainId>bundles: Vec<u8>previous_height: Option<BlockHeight>

The height of the sender’s previous block that sent messages to this recipient (before the first bundle). Absent if this is the first message ever.