pub struct ValidatorNodeClient<T> { /* private fields */ }Expand description
How to communicate with a validator or a local node.
Implementations
Sourceimpl<T> ValidatorNodeClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> ValidatorNodeClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ValidatorNodeClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn handle_block_proposal(
&mut self,
request: impl IntoRequest<BlockProposal>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_block_proposal( &mut self, request: impl IntoRequest<BlockProposal>, ) -> Result<Response<ChainInfoResult>, Status>
Propose a new block.
Sourcepub async fn handle_lite_certificate(
&mut self,
request: impl IntoRequest<LiteCertificate>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_lite_certificate( &mut self, request: impl IntoRequest<LiteCertificate>, ) -> Result<Response<ChainInfoResult>, Status>
Process a certificate without value.
pub async fn handle_confirmed_certificate( &mut self, request: impl IntoRequest<HandleConfirmedCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_validated_certificate( &mut self, request: impl IntoRequest<HandleValidatedCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_timeout_certificate( &mut self, request: impl IntoRequest<HandleTimeoutCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Sourcepub async fn handle_chain_info_query(
&mut self,
request: impl IntoRequest<ChainInfoQuery>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_chain_info_query( &mut self, request: impl IntoRequest<ChainInfoQuery>, ) -> Result<Response<ChainInfoResult>, Status>
Handle information queries for this chain.
Sourcepub async fn subscribe(
&mut self,
request: impl IntoRequest<SubscriptionRequest>,
) -> Result<Response<Streaming<Notification>>, Status>
pub async fn subscribe( &mut self, request: impl IntoRequest<SubscriptionRequest>, ) -> Result<Response<Streaming<Notification>>, Status>
Subscribe to notifications for a set of Chain Ids.
Sourcepub async fn get_version_info(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<VersionInfo>, Status>
pub async fn get_version_info( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<VersionInfo>, Status>
Request the node’s version info.
Sourcepub async fn get_network_description(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<NetworkDescription>, Status>
pub async fn get_network_description( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<NetworkDescription>, Status>
Request the network description seen by this node.
Sourcepub async fn download_blob(
&mut self,
request: impl IntoRequest<BlobId>,
) -> Result<Response<BlobContent>, Status>
pub async fn download_blob( &mut self, request: impl IntoRequest<BlobId>, ) -> Result<Response<BlobContent>, Status>
Download a blob.
Sourcepub async fn download_blobs(
&mut self,
request: impl IntoRequest<BlobIds>,
) -> Result<Response<Streaming<BlobContent>>, Status>
pub async fn download_blobs( &mut self, request: impl IntoRequest<BlobIds>, ) -> Result<Response<Streaming<BlobContent>>, Status>
Download a batch of blobs as a stream.
Sourcepub async fn download_pending_blob(
&mut self,
request: impl IntoRequest<PendingBlobRequest>,
) -> Result<Response<PendingBlobResult>, Status>
pub async fn download_pending_blob( &mut self, request: impl IntoRequest<PendingBlobRequest>, ) -> Result<Response<PendingBlobResult>, Status>
Download a blob that belongs to a pending block on the given chain.
Sourcepub async fn handle_pending_blob(
&mut self,
request: impl IntoRequest<HandlePendingBlobRequest>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_pending_blob( &mut self, request: impl IntoRequest<HandlePendingBlobRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Handle a blob that belongs to a pending block on the given chain.
Sourcepub async fn upload_blob(
&mut self,
request: impl IntoRequest<BlobContent>,
) -> Result<Response<BlobId>, Status>
pub async fn upload_blob( &mut self, request: impl IntoRequest<BlobContent>, ) -> Result<Response<BlobId>, Status>
Upload a blob. Returns an error if the validator has not seen a certificate using this blob.
Sourcepub async fn download_certificate(
&mut self,
request: impl IntoRequest<CryptoHash>,
) -> Result<Response<Certificate>, Status>
pub async fn download_certificate( &mut self, request: impl IntoRequest<CryptoHash>, ) -> Result<Response<Certificate>, Status>
Download a certificate.
Sourcepub async fn download_certificates(
&mut self,
request: impl IntoRequest<CertificatesBatchRequest>,
) -> Result<Response<CertificatesBatchResponse>, Status>
pub async fn download_certificates( &mut self, request: impl IntoRequest<CertificatesBatchRequest>, ) -> Result<Response<CertificatesBatchResponse>, Status>
Download a batch of certificates.
Sourcepub async fn download_certificates_by_heights(
&mut self,
request: impl IntoRequest<DownloadCertificatesByHeightsRequest>,
) -> Result<Response<CertificatesBatchResponse>, Status>
pub async fn download_certificates_by_heights( &mut self, request: impl IntoRequest<DownloadCertificatesByHeightsRequest>, ) -> Result<Response<CertificatesBatchResponse>, Status>
/ Download a batch of certificates by heights.
Sourcepub async fn download_raw_certificates_by_heights(
&mut self,
request: impl IntoRequest<DownloadCertificatesByHeightsRequest>,
) -> Result<Response<RawCertificatesBatch>, Status>
pub async fn download_raw_certificates_by_heights( &mut self, request: impl IntoRequest<DownloadCertificatesByHeightsRequest>, ) -> Result<Response<RawCertificatesBatch>, Status>
Download a batch of certificates, in serialized form, by their heights.
Sourcepub async fn blob_last_used_by(
&mut self,
request: impl IntoRequest<BlobId>,
) -> Result<Response<CryptoHash>, Status>
pub async fn blob_last_used_by( &mut self, request: impl IntoRequest<BlobId>, ) -> Result<Response<CryptoHash>, Status>
Return the hash of the Certificate that last used a blob.
Sourcepub async fn missing_blob_ids(
&mut self,
request: impl IntoRequest<BlobIds>,
) -> Result<Response<BlobIds>, Status>
pub async fn missing_blob_ids( &mut self, request: impl IntoRequest<BlobIds>, ) -> Result<Response<BlobIds>, Status>
Return the BlobIds that are not contained as Blob.
Sourcepub async fn blob_last_used_by_certificate(
&mut self,
request: impl IntoRequest<BlobId>,
) -> Result<Response<Certificate>, Status>
pub async fn blob_last_used_by_certificate( &mut self, request: impl IntoRequest<BlobId>, ) -> Result<Response<Certificate>, Status>
Returns the certificate that last used the blob.
Sourcepub async fn previous_event_blocks(
&mut self,
request: impl IntoRequest<PreviousEventBlocksRequest>,
) -> Result<Response<PreviousEventBlocksResponse>, Status>
pub async fn previous_event_blocks( &mut self, request: impl IntoRequest<PreviousEventBlocksRequest>, ) -> Result<Response<PreviousEventBlocksResponse>, Status>
Returns the previous event blocks for a chain’s streams.