pub struct ValidatorWorkerClient<T> { /* private fields */ }Expand description
Interface provided by each physical shard (aka “worker”) of a validator or a local node.
- All commands return either the current chain info or an error.
- Repeating commands produces no changes and returns no error.
- Some handlers may return cross-chain requests (messages to be communicated to other workers).
Implementations
Sourceimpl<T> ValidatorWorkerClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> ValidatorWorkerClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ValidatorWorkerClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn handle_block_proposal(
&mut self,
request: impl IntoRequest<BlockProposal>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_block_proposal( &mut self, request: impl IntoRequest<BlockProposal>, ) -> Result<Response<ChainInfoResult>, Status>
Propose a new block.
Sourcepub async fn handle_lite_certificate(
&mut self,
request: impl IntoRequest<LiteCertificate>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_lite_certificate( &mut self, request: impl IntoRequest<LiteCertificate>, ) -> Result<Response<ChainInfoResult>, Status>
Process a certificate without value.
pub async fn handle_confirmed_certificate( &mut self, request: impl IntoRequest<HandleConfirmedCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_validated_certificate( &mut self, request: impl IntoRequest<HandleValidatedCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_timeout_certificate( &mut self, request: impl IntoRequest<HandleTimeoutCertificateRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Sourcepub async fn handle_chain_info_query(
&mut self,
request: impl IntoRequest<ChainInfoQuery>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_chain_info_query( &mut self, request: impl IntoRequest<ChainInfoQuery>, ) -> Result<Response<ChainInfoResult>, Status>
Handle information queries for this chain.
Sourcepub async fn download_pending_blob(
&mut self,
request: impl IntoRequest<PendingBlobRequest>,
) -> Result<Response<PendingBlobResult>, Status>
pub async fn download_pending_blob( &mut self, request: impl IntoRequest<PendingBlobRequest>, ) -> Result<Response<PendingBlobResult>, Status>
Download a blob that belongs to a pending block on the given chain.
Sourcepub async fn handle_pending_blob(
&mut self,
request: impl IntoRequest<HandlePendingBlobRequest>,
) -> Result<Response<ChainInfoResult>, Status>
pub async fn handle_pending_blob( &mut self, request: impl IntoRequest<HandlePendingBlobRequest>, ) -> Result<Response<ChainInfoResult>, Status>
Handle a blob that belongs to a pending block on the given chain.
Sourcepub async fn handle_cross_chain_request(
&mut self,
request: impl IntoRequest<CrossChainRequest>,
) -> Result<Response<()>, Status>
pub async fn handle_cross_chain_request( &mut self, request: impl IntoRequest<CrossChainRequest>, ) -> Result<Response<()>, Status>
Handle a (trusted!) cross-chain request.
Sourcepub async fn previous_event_blocks(
&mut self,
request: impl IntoRequest<PreviousEventBlocksRequest>,
) -> Result<Response<PreviousEventBlocksResponse>, Status>
pub async fn previous_event_blocks( &mut self, request: impl IntoRequest<PreviousEventBlocksRequest>, ) -> Result<Response<PreviousEventBlocksResponse>, Status>
Returns the previous event blocks for a chain’s streams.