pub struct NodeOptions {
pub send_timeout: Duration,
pub recv_timeout: Duration,
pub retry_delay: Duration,
pub max_retries: u32,
pub max_backoff: Duration,
}Expand description
Options for configuring the clients created by a node provider.
Fields
send_timeout: DurationThe maximum time to wait when sending a request.
recv_timeout: DurationThe maximum time to wait when receiving a response.
retry_delay: DurationThe delay between retries.
max_retries: u32The maximum number of retries for a request.
max_backoff: DurationThe maximum backoff delay between retries.