RpcMessage

Enum RpcMessage 

pub enum RpcMessage {
Show 33 variants BlockProposal(Box<BlockProposal>), TimeoutCertificate(Box<HandleTimeoutCertificateRequest>), ValidatedCertificate(Box<HandleValidatedCertificateRequest>), ConfirmedCertificate(Box<HandleConfirmedCertificateRequest>), LiteCertificate(Box<HandleLiteCertRequest<'static>>), ChainInfoQuery(Box<ChainInfoQuery>), UploadBlob(Box<BlobContent>), DownloadBlob(Box<BlobId>), DownloadPendingBlob(Box<(ChainId, BlobId)>), HandlePendingBlob(Box<(ChainId, BlobContent)>), DownloadConfirmedBlock(Box<CryptoHash>), DownloadCertificates(Vec<CryptoHash>), DownloadCertificatesByHeights(ChainId, Vec<BlockHeight>), BlobLastUsedBy(Box<BlobId>), MissingBlobIds(Vec<BlobId>), VersionInfoQuery, NetworkDescriptionQuery, Vote(Box<LiteVote>), ChainInfoResponse(Box<ChainInfoResponse>), Error(Box<NodeError>), VersionInfoResponse(Box<VersionInfo>), NetworkDescriptionResponse(Box<NetworkDescription>), UploadBlobResponse(Box<BlobId>), DownloadBlobResponse(Box<BlobContent>), DownloadPendingBlobResponse(Box<BlobContent>), DownloadConfirmedBlockResponse(Box<ConfirmedBlock>), DownloadCertificatesResponse(Vec<ConfirmedBlockCertificate>), DownloadCertificatesByHeightsResponse(Vec<ConfirmedBlockCertificate>), BlobLastUsedByResponse(Box<CryptoHash>), MissingBlobIdsResponse(Vec<BlobId>), CrossChainRequest(Box<CrossChainRequest>), BlobLastUsedByCertificate(Box<BlobId>), BlobLastUsedByCertificateResponse(Box<ConfirmedBlockCertificate>),
}

Variants



BlockProposal(Box<BlockProposal>)



TimeoutCertificate(Box<HandleTimeoutCertificateRequest>)



ValidatedCertificate(Box<HandleValidatedCertificateRequest>)



ConfirmedCertificate(Box<HandleConfirmedCertificateRequest>)



LiteCertificate(Box<HandleLiteCertRequest<'static>>)



ChainInfoQuery(Box<ChainInfoQuery>)



UploadBlob(Box<BlobContent>)



DownloadBlob(Box<BlobId>)



DownloadPendingBlob(Box<(ChainId, BlobId)>)



HandlePendingBlob(Box<(ChainId, BlobContent)>)



DownloadConfirmedBlock(Box<CryptoHash>)



DownloadCertificates(Vec<CryptoHash>)



DownloadCertificatesByHeights(ChainId, Vec<BlockHeight>)



BlobLastUsedBy(Box<BlobId>)



MissingBlobIds(Vec<BlobId>)



VersionInfoQuery



NetworkDescriptionQuery



Vote(Box<LiteVote>)



ChainInfoResponse(Box<ChainInfoResponse>)



Error(Box<NodeError>)



VersionInfoResponse(Box<VersionInfo>)



NetworkDescriptionResponse(Box<NetworkDescription>)



UploadBlobResponse(Box<BlobId>)



DownloadBlobResponse(Box<BlobContent>)



DownloadPendingBlobResponse(Box<BlobContent>)



DownloadConfirmedBlockResponse(Box<ConfirmedBlock>)



DownloadCertificatesResponse(Vec<ConfirmedBlockCertificate>)



DownloadCertificatesByHeightsResponse(Vec<ConfirmedBlockCertificate>)



BlobLastUsedByResponse(Box<CryptoHash>)



MissingBlobIdsResponse(Vec<BlobId>)



CrossChainRequest(Box<CrossChainRequest>)



BlobLastUsedByCertificate(Box<BlobId>)



BlobLastUsedByCertificateResponse(Box<ConfirmedBlockCertificate>)

Implementations

Source

impl RpcMessage

pub fn target_chain_id(&self) -> Option<ChainId>

Obtains the ChainId of the chain targeted by this message, if there is one.

Only inbound messages have target chains.

pub fn is_local_message(&self) -> bool

Whether this message is “local” i.e. will be executed locally on the proxy or if it’ll be proxied to the server.